CacheStrategy enum

The caching strategy applied per request (or globally as default).

Inheritance
Available extensions

Values

cacheFirst → const CacheStrategy

Return cached data if fresh; fetch from network if expired or missing.

networkFirst → const CacheStrategy

Always try the network first; fall back to cache on failure or offline.

staleWhileRevalidate → const CacheStrategy

Return cached data immediately (even if stale); refresh cache in background.

networkOnly → const CacheStrategy

Never read from or write to cache.

cacheOnly → const CacheStrategy

Never hit the network — only serve from cache.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CacheStrategy>
A constant List of the values in this enum, in order of their declaration.