ConnectivityMonitor class

Tracks real-time device connectivity.

Constructors

ConnectivityMonitor({Connectivity? connectivity})

Properties

hashCode int
The hash code for this object.
no setterinherited
isOnline bool
no setter
onChanged Stream<bool>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkNow() Future<bool>
dispose() → void
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited